==> ejc-prjfinance-impl-3.0.1-20210724.082301-28-sources.jar: com/ejianc/business/prjfinance/bean/ProjectDutyLetterCostlistEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.math.BigDecimal;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * <p>
 * 项目目标责任书--费用清单
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
@TableName("ejc_prjfinance_dutyletter_costlist")
public class ProjectDutyLetterCostlistEntity extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 费用名称
     */
    @TableField("cost_id")
    private Long costId;

    /**
     * 费用名称
     */
    @TableField("cost_name")
    private String costName;

    /**
     * 增加/扣除
     */
    @TableField("add_or_delete")
    private String addOrDelete;

    /**
     * 数值
     */
    @TableField("formula")
    private String formula;

    /**
     * 公式--实际值
     */
    @TableField("formula_describe")
    private String formulaDescribe;

    /**
     * 金额
     */
    @TableField("amount")
    private BigDecimal amount;

    /**
     * 备注
     */
    @TableField("remarks")
    private String remarks;
    
    /**
     * 主表id
     */
    @TableField("duty_letter_id")
    private Long dutyLetterId;
    
	public String getCostName() {
		return costName;
	}

	public void setCostName(String costName) {
		this.costName = costName;
	}

	public Long getCostId() {
		return costId;
	}

	public void setCostId(Long costId) {
		this.costId = costId;
	}

	public String getAddOrDelete() {
		return addOrDelete;
	}

	public void setAddOrDelete(String addOrDelete) {
		this.addOrDelete = addOrDelete;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public String getFormulaDescribe() {
		return formulaDescribe;
	}

	public void setFormulaDescribe(String formulaDescribe) {
		this.formulaDescribe = formulaDescribe;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public Long getDutyLetterId() {
		return dutyLetterId;
	}

	public void setDutyLetterId(Long dutyLetterId) {
		this.dutyLetterId = dutyLetterId;
	}
	
}

==> ejc-prjfinance-impl-3.0.1-20210804.073242-68-sources.jar: com/ejianc/business/prjfinance/bean/ProjectDutyLetterCostlistEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.math.BigDecimal;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * <p>
 * 项目目标责任书--费用清单
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
@TableName("ejc_prjfinance_dutyletter_costlist")
public class ProjectDutyLetterCostlistEntity extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 费用名称
     */
    @TableField("cost_id")
    private Long costId;

    /**
     * 费用名称
     */
    @TableField("cost_name")
    private String costName;

    /**
     * 增加/扣除
     */
    @TableField("back_or_del")
    private String backOrDel;

    /**
     * 数值
     */
    @TableField("formula")
    private String formula;

    /**
     * 公式--实际值
     */
    @TableField("formula_describe")
    private String formulaDescribe;

    /**
     * 金额
     */
    @TableField("amount")
    private BigDecimal amount;

    /**
     * 备注
     */
    @TableField("remarks")
    private String remarks;
    
    /**
     * 主表id
     */
    @TableField("duty_letter_id")
    private Long dutyLetterId;
    
	public String getCostName() {
		return costName;
	}

	public void setCostName(String costName) {
		this.costName = costName;
	}

	public Long getCostId() {
		return costId;
	}

	public void setCostId(Long costId) {
		this.costId = costId;
	}

	public String getBackOrDel() {
		return backOrDel;
	}

	public void setBackOrDel(String backOrDel) {
		this.backOrDel = backOrDel;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public String getFormulaDescribe() {
		return formulaDescribe;
	}

	public void setFormulaDescribe(String formulaDescribe) {
		this.formulaDescribe = formulaDescribe;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public Long getDutyLetterId() {
		return dutyLetterId;
	}

	public void setDutyLetterId(Long dutyLetterId) {
		this.dutyLetterId = dutyLetterId;
	}
	
}
